==> gatsby-sports-theme-1.0.11.tgz: package/src/components/atoms/cards/operator-card/index.js <==
/* eslint-disable react-hooks/rules-of-hooks */
import React, { useContext } from 'react';
import StarRating from '~molecules/star-rating/one-star';
import OperatorCta from '~atoms/button/operator-cta';
import { Context } from '~context/MainProvider';
import { prettyTracker, imagePrettyUrl, translate, getAltText } from '~helpers/getters';
import LazyImage from '~hooks/lazy-image';
import Link from '~hooks/link';
import Bonus from '~molecules/bonus/template-one';
import styles from './operator-card.module.scss';

export default function index({ item, page }) {
  const operator = item.relation;
  const pageTemplate = page.relation_type;
  const prettyLink = prettyTracker(operator, 'main', false, pageTemplate);
  const operatorRating = operator.rating;
  const { translations } = useContext(Context) || {};
  const reviewPath = operator.review_link ? `/${operator.review_link}` : operator.path || '/';
  const imageObject = operator?.standardised_logo_url_object || operator?.logo_url_object;
  return (
    <div className={styles.container}>
      <div className={styles.logo}>
        <a
          href={prettyLink}
          title={operator.name}
          className="casinos-top-list-gtm logo-cta"
          target="_blank"
          rel="noreferrer"
          aria-label={`${operator.name} Link`}
        >
          <LazyImage
            alt={getAltText(imageObject, operator.name)}
            src={imagePrettyUrl(imageObject?.filename || operator?.logo_url, 86, 86)}
            width={86}
            height={86}
          />
        </a>
        <div>
          <p>{operator.name}</p>
          <StarRating numOfStars={5} rating={operatorRating} />
          <Link className={`${styles.reviewLink} toplist-variant-one-gtm`} to={reviewPath}>
            {`${translate(translations, 'read_review', 'Review')}`}
          </Link>
        </div>
      </div>
      <a
        href={prettyLink}
        target="_blank"
        rel="noreferrer"
        className={`toplist-variant-one-gtm bonus-cta ${styles.oneliner}`}
      >
        <Bonus item={operator} tracker="main" />
      </a>
      <OperatorCta
        operator={operator}
        tracker="main"
        gtmClass="toplist-operator-cta-gtm"
        pageTemplate={pageTemplate}
      />
    </div>
  );
}

==> gatsby-sports-theme-1.0.13.tgz: package/src/components/atoms/cards/operator-card/index.js <==
/* eslint-disable react-hooks/rules-of-hooks */
import React from 'react';
import Bonus from 'gatsby-core-theme/src/components/molecules/bonus-box/template-four';
import ReviewLink from 'gatsby-core-theme/src/components/atoms/review-link';
import StarRating from '~molecules/star-rating/one-star';
import OperatorCta from '~atoms/button/operator-cta';
import { prettyTracker, imagePrettyUrl, getAltText } from '~helpers/getters';
import LazyImage from '~hooks/lazy-image';
import styles from './operator-card.module.scss';

export default function index({ item, page }) {
  const operator = item.relation;
  const pageTemplate = page.relation_type;
  const prettyLink = prettyTracker(operator, 'main', false, pageTemplate);
  const operatorRating = operator.rating;
  const reviewPath = item?.path || null;
  const imageObject = operator?.standardised_logo_url_object || operator?.logo_url_object;
  return (
    <div className={styles.container}>
      <div className={styles.logo}>
        <a
          href={prettyLink}
          title={operator.name}
          className="casinos-top-list-gtm logo-cta"
          target="_blank"
          rel="noreferrer"
          aria-label={`${operator.name} Link`}
        >
          <LazyImage
            alt={getAltText(imageObject, operator.name)}
            src={imagePrettyUrl(imageObject?.filename || operator?.logo_url, 86, 86)}
            width={86}
            height={86}
          />
        </a>
        <div>
          <p>{operator.name}</p>
          <StarRating numOfStars={5} rating={operatorRating} />
          {reviewPath && <ReviewLink reviewPath={reviewPath} operatorName={operator?.name} />}
        </div>
      </div>
      <a
        href={prettyLink}
        target="_blank"
        rel="noreferrer"
        className={`toplist-variant-one-gtm bonus-cta ${styles.oneliner}`}
      >
        <Bonus item={operator} tracker="main" />
      </a>
      <OperatorCta
        operator={operator}
        tracker="main"
        gtmClass="toplist-operator-cta-gtm"
        pageTemplate={pageTemplate}
      />
    </div>
  );
}
